==> ejc-settlementmanage-impl-3.0.0-20221210.112757-136-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookStatementDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-收入明细表-工程量清单结算表
 * 
 * @author generator
 * 
 */
public class SettlementBookStatementDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String listingCode; // 清单编码
    private java.lang.String units; // 单位
    private java.math.BigDecimal quantities; // 工程量
    private java.math.BigDecimal extaxUnitprice; // 合同单价除税
    private java.math.BigDecimal intaxUnitprice; // 合同单价含税
    private java.math.BigDecimal exsettlementUnitprice; // 结算除税单价
    private java.math.BigDecimal insettlementUnitprice; // 结算含税单价
    private java.math.BigDecimal extaxAddition; // 除税合价
    private java.math.BigDecimal intaxAddition; // 含税合价
    private java.lang.String remarks; // 备注
    private java.lang.String partProjectName; // 分部分项工程名称
    private java.lang.String source; // 来源
    private java.lang.String isDeleted; // 是否允许删除
    private java.math.BigDecimal accruingAmountsNotax;  //累计报量金额(除税)
    private java.math.BigDecimal accruingAmountsTax;  //累计报量金额(含税税)
    private java.math.BigDecimal thisAmountsNotax;  //本次报量金额(除税)
    private java.math.BigDecimal thisAmountsTax;  //本次报量金额(含税)
    private java.math.BigDecimal cumulativeEngineeringQuantity;  //累计报量工程
    private java.math.BigDecimal thisEngineeringQuantity;  //本期报量工程
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String errorMsg;
    private java.lang.String innercode;
    private String section; // 区段
    private String subitemDesc; // 子目特征描述
    private List<SettlementBookStatementDetailVO> children = new ArrayList<>();

    public BigDecimal getAccruingAmountsNotax() {
        return accruingAmountsNotax;
    }

    public void setAccruingAmountsNotax(BigDecimal accruingAmountsNotax) {
        this.accruingAmountsNotax = accruingAmountsNotax;
    }

    public BigDecimal getAccruingAmountsTax() {
        return accruingAmountsTax;
    }

    public void setAccruingAmountsTax(BigDecimal accruingAmountsTax) {
        this.accruingAmountsTax = accruingAmountsTax;
    }

    public BigDecimal getThisAmountsNotax() {
        return thisAmountsNotax;
    }

    public void setThisAmountsNotax(BigDecimal thisAmountsNotax) {
        this.thisAmountsNotax = thisAmountsNotax;
    }

    public BigDecimal getThisAmountsTax() {
        return thisAmountsTax;
    }

    public void setThisAmountsTax(BigDecimal thisAmountsTax) {
        this.thisAmountsTax = thisAmountsTax;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public List<SettlementBookStatementDetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementBookStatementDetailVO> children) {
        this.children = children;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }

    public BigDecimal getQuantities() {
        return quantities;
    }

    public void setQuantities(BigDecimal quantities) {
        this.quantities = quantities;
    }

    public BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    public void setExtaxUnitprice(BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 结算除税单价
     */
    public java.math.BigDecimal getExsettlementUnitprice() {
        return exsettlementUnitprice;
    }

    /**
     * 结算除税单价
     */
    public void setExsettlementUnitprice(java.math.BigDecimal exsettlementUnitprice) {
        this.exsettlementUnitprice = exsettlementUnitprice;
    }
    /**
     * 结算含税单价
     */
    public java.math.BigDecimal getInsettlementUnitprice() {
        return insettlementUnitprice;
    }

    /**
     * 结算含税单价
     */
    public void setInsettlementUnitprice(java.math.BigDecimal insettlementUnitprice) {
        this.insettlementUnitprice = insettlementUnitprice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExtaxAddition() {
        return extaxAddition;
    }

    /**
     * 除税合价
     */
    public void setExtaxAddition(java.math.BigDecimal extaxAddition) {
        this.extaxAddition = extaxAddition;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIntaxAddition() {
        return intaxAddition;
    }

    /**
     * 含税合价
     */
    public void setIntaxAddition(java.math.BigDecimal intaxAddition) {
        this.intaxAddition = intaxAddition;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getPartProjectName() {
        return partProjectName;
    }

    public void setPartProjectName(String partProjectName) {
        this.partProjectName = partProjectName;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }

    public BigDecimal getCumulativeEngineeringQuantity() {
        return cumulativeEngineeringQuantity;
    }

    public void setCumulativeEngineeringQuantity(BigDecimal cumulativeEngineeringQuantity) {
        this.cumulativeEngineeringQuantity = cumulativeEngineeringQuantity;
    }

    public BigDecimal getThisEngineeringQuantity() {
        return thisEngineeringQuantity;
    }

    public void setThisEngineeringQuantity(BigDecimal thisEngineeringQuantity) {
        this.thisEngineeringQuantity = thisEngineeringQuantity;
    }

    public String getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(String isDeleted) {
        this.isDeleted = isDeleted;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20251027.062237-321-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookStatementDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-收入明细表-工程量清单结算表
 * 
 * @author generator
 * 
 */
public class SettlementBookStatementDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Long contractId; // 合同id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String listingCode; // 清单编码
    private java.lang.String units; // 单位
    private java.math.BigDecimal quantities; // 工程量
    private java.math.BigDecimal extaxUnitprice; // 合同单价除税
    private java.math.BigDecimal intaxUnitprice; // 合同单价含税
    private java.math.BigDecimal exsettlementUnitprice; // 结算除税单价
    private java.math.BigDecimal insettlementUnitprice; // 结算含税单价
    private java.math.BigDecimal extaxAddition; // 除税合价
    private java.math.BigDecimal intaxAddition; // 含税合价
    private java.lang.String remarks; // 备注
    private java.lang.String partProjectName; // 分部分项工程名称
    private java.lang.String source; // 来源
    private java.lang.String isDeleted; // 是否允许删除
    private java.math.BigDecimal accruingAmountsNotax;  //累计报量金额(除税)
    private java.math.BigDecimal accruingAmountsTax;  //累计报量金额(含税税)
    private java.math.BigDecimal thisAmountsNotax;  //本次报量金额(除税)
    private java.math.BigDecimal thisAmountsTax;  //本次报量金额(含税)
    private java.math.BigDecimal cumulativeEngineeringQuantity;  //累计报量工程
    private java.math.BigDecimal thisEngineeringQuantity;  //本期报量工程
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String errorMsg;
    private java.lang.String innercode;
    private String section; // 区段
    private String subitemDesc; // 子目特征描述
    private List<SettlementBookStatementDetailVO> children = new ArrayList<>();

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getAccruingAmountsNotax() {
        return accruingAmountsNotax;
    }

    public void setAccruingAmountsNotax(BigDecimal accruingAmountsNotax) {
        this.accruingAmountsNotax = accruingAmountsNotax;
    }

    public BigDecimal getAccruingAmountsTax() {
        return accruingAmountsTax;
    }

    public void setAccruingAmountsTax(BigDecimal accruingAmountsTax) {
        this.accruingAmountsTax = accruingAmountsTax;
    }

    public BigDecimal getThisAmountsNotax() {
        return thisAmountsNotax;
    }

    public void setThisAmountsNotax(BigDecimal thisAmountsNotax) {
        this.thisAmountsNotax = thisAmountsNotax;
    }

    public BigDecimal getThisAmountsTax() {
        return thisAmountsTax;
    }

    public void setThisAmountsTax(BigDecimal thisAmountsTax) {
        this.thisAmountsTax = thisAmountsTax;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public List<SettlementBookStatementDetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementBookStatementDetailVO> children) {
        this.children = children;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }

    public BigDecimal getQuantities() {
        return quantities;
    }

    public void setQuantities(BigDecimal quantities) {
        this.quantities = quantities;
    }

    public BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    public void setExtaxUnitprice(BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 合同单价含税
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 结算除税单价
     */
    public java.math.BigDecimal getExsettlementUnitprice() {
        return exsettlementUnitprice;
    }

    /**
     * 结算除税单价
     */
    public void setExsettlementUnitprice(java.math.BigDecimal exsettlementUnitprice) {
        this.exsettlementUnitprice = exsettlementUnitprice;
    }
    /**
     * 结算含税单价
     */
    public java.math.BigDecimal getInsettlementUnitprice() {
        return insettlementUnitprice;
    }

    /**
     * 结算含税单价
     */
    public void setInsettlementUnitprice(java.math.BigDecimal insettlementUnitprice) {
        this.insettlementUnitprice = insettlementUnitprice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExtaxAddition() {
        return extaxAddition;
    }

    /**
     * 除税合价
     */
    public void setExtaxAddition(java.math.BigDecimal extaxAddition) {
        this.extaxAddition = extaxAddition;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIntaxAddition() {
        return intaxAddition;
    }

    /**
     * 含税合价
     */
    public void setIntaxAddition(java.math.BigDecimal intaxAddition) {
        this.intaxAddition = intaxAddition;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getPartProjectName() {
        return partProjectName;
    }

    public void setPartProjectName(String partProjectName) {
        this.partProjectName = partProjectName;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }

    public BigDecimal getCumulativeEngineeringQuantity() {
        return cumulativeEngineeringQuantity;
    }

    public void setCumulativeEngineeringQuantity(BigDecimal cumulativeEngineeringQuantity) {
        this.cumulativeEngineeringQuantity = cumulativeEngineeringQuantity;
    }

    public BigDecimal getThisEngineeringQuantity() {
        return thisEngineeringQuantity;
    }

    public void setThisEngineeringQuantity(BigDecimal thisEngineeringQuantity) {
        this.thisEngineeringQuantity = thisEngineeringQuantity;
    }

    public String getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(String isDeleted) {
        this.isDeleted = isDeleted;
    }
}
